Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(430)

Unified Diff: ios/web/navigation/navigation_manager_impl.h

Issue 2779383002: implement user agent override option. (Closed)
Patch Set: Rebase Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ios/chrome/browser/ui/browser_view_controller.mm ('k') | ios/web/navigation/navigation_manager_impl.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ios/web/navigation/navigation_manager_impl.h
diff --git a/ios/web/navigation/navigation_manager_impl.h b/ios/web/navigation/navigation_manager_impl.h
index 9a4298674b0861990db2f5e3f10c384d424388be..b2bb5a200f12dae41974a4e219cd359fedaab118 100644
--- a/ios/web/navigation/navigation_manager_impl.h
+++ b/ios/web/navigation/navigation_manager_impl.h
@@ -95,15 +95,16 @@ class NavigationManagerImpl : public NavigationManager {
const Referrer& referrer,
ui::PageTransition type);
// Adds a new item with the given url, referrer, navigation type, and
// initiation type, making it the pending item. If pending item is the same as
// the current item, this does nothing. |referrer| may be nil if there isn't
// one. The item starts out as pending, and will be lost unless
// |-commitPendingItem| is called.
void AddPendingItem(const GURL& url,
const web::Referrer& referrer,
ui::PageTransition navigation_type,
- NavigationInitiationType initiation_type);
+ NavigationInitiationType initiation_type,
+ UserAgentOverrideOption user_agent_override_option);
// Temporary method. Returns a vector of NavigationItems corresponding to
// the SessionEntries of the uderlying CRWSessionController.
@@ -138,7 +139,6 @@ class NavigationManagerImpl : public NavigationManager {
NavigationItemList GetForwardItems() const override;
void CopyStateFromAndPrune(const NavigationManager* source) override;
bool CanPruneAllButLastCommittedItem() const override;
- void OverrideDesktopUserAgentForNextPendingItem() override;
// Returns the current list of transient url rewriters, passing ownership to
// the caller.
@@ -170,12 +170,6 @@ class NavigationManagerImpl : public NavigationManager {
// URL.
NavigationItem* GetLastCommittedNonAppSpecificItem() const;
- // If true, override navigation item's useDesktopUserAgent flag and always
- // create the pending entry using the desktop user agent.
- // TODO(crbug.com/692303): Remove this when overriding the user agent doesn't
- // create a new NavigationItem.
- bool override_desktop_user_agent_for_next_pending_item_;
-
// The primary delegate for this manager.
NavigationManagerDelegate* delegate_;
« no previous file with comments | « ios/chrome/browser/ui/browser_view_controller.mm ('k') | ios/web/navigation/navigation_manager_impl.mm » ('j') | no next file with comments »
@@ -95,15 +95,16 @@ class NavigationManagerImpl : public NavigationManager {
const Referrer& referrer,
ui::PageTransition type);
- // Adds a new item with the given url, referrer, navigation type, and
- // initiation type, making it the pending item. If pending item is the same as
- // the current item, this does nothing. |referrer| may be nil if there isn't
- // one. The item starts out as pending, and will be lost unless
- // |-commitPendingItem| is called.
+ // Adds a new item with the given url, referrer, navigation type, initiation
+ // type and user agent override option, making it the pending item. If pending
+ // item is the same as the current item, this does nothing. |referrer| may be
+ // nil if there isn't one. The item starts out as pending, and will be lost
+ // unless |-commitPendingItem| is called.
void AddPendingItem(const GURL& url,
const web::Referrer& referrer,

Powered by Google App Engine
This is Rietveld 408576698